package pgp.hkp.operation

import pgp.hkp.HKPApi.Companion.OP_GET
import pgp.hkp.HKPServerInfo
import pgp.hkp.OpenPgpImplementation
import java.net.http.HttpClient

class Get(val http: HttpClient,
          val service: HKPServerInfo,
          val openpgp: OpenPgpImplementation) {

    fun byKeyId(keyId: Long): LookupRequest {
        return LookupRequest(http, service, OP_GET, "0x${openpgp.hexKeyId(keyId)}")
    }

    fun byFingerprint(fingerprint: ByteArray): LookupRequest {
        return byFingerprint(openpgp.hexFingerprint(fingerprint))
    }

    fun byFingerprint(fingerprint: CharSequence): LookupRequest {
        require(fingerprint.length in listOf(32, 40, 64)) {
            "Fingerprint strings are either 32 (v3), 40 (v4) or 64 (v6) hexadecimal digits."
        }
        return LookupRequest(http, service, OP_GET, "0x$fingerprint")
    }

    fun byUserId(userId: CharSequence): LookupRequest {
        return LookupRequest(http, service, OP_GET, userId.toString())
    }
}